==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ConsoleStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleStatusFluentImpl<A extends io.fabric8.openshift.api.model.ConsoleStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ConsoleStatusFluent<A>{
  public ConsoleStatusFluentImpl() {
  }
  public ConsoleStatusFluentImpl(io.fabric8.openshift.api.model.ConsoleStatus instance) {
    this.withConsoleURL(instance.getConsoleURL()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String consoleURL;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getConsoleURL() {
    return this.consoleURL;
  }
  public A withConsoleURL(java.lang.String consoleURL) {
    this.consoleURL=consoleURL; return (A) this;
  }
  public java.lang.Boolean hasConsoleURL() {
    return this.consoleURL != null;
  }
  
  /**
   * Method is deprecated. use withConsoleURL instead.
   */
  @java.lang.Deprecated
  public A withNewConsoleURL(java.lang.String arg0) {
    return (A)withConsoleURL(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleStatusFluentImpl that = (ConsoleStatusFluentImpl) o;
    if (consoleURL != null ? !consoleURL.equals(that.consoleURL) :that.consoleURL != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(consoleURL,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ConsoleStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleStatusFluentImpl<A extends io.fabric8.openshift.api.model.ConsoleStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ConsoleStatusFluent<A>{
  public ConsoleStatusFluentImpl() {
  }
  public ConsoleStatusFluentImpl(io.fabric8.openshift.api.model.ConsoleStatus instance) {
    this.withConsoleURL(instance.getConsoleURL()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String consoleURL;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getConsoleURL() {
    return this.consoleURL;
  }
  public A withConsoleURL(java.lang.String consoleURL) {
    this.consoleURL=consoleURL; return (A) this;
  }
  public java.lang.Boolean hasConsoleURL() {
    return this.consoleURL != null;
  }
  
  /**
   * Method is deprecated. use withConsoleURL instead.
   */
  @java.lang.Deprecated
  public A withNewConsoleURL(java.lang.String arg0) {
    return (A)withConsoleURL(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleStatusFluentImpl that = (ConsoleStatusFluentImpl) o;
    if (consoleURL != null ? !consoleURL.equals(that.consoleURL) :that.consoleURL != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(consoleURL,  additionalProperties,  super.hashCode());
  }
  
}
